@@ -17,10 +17,10 @@ Z = data[:, 1] + 1j * data[:, 2]
 
 def test_BaseCircuit():
     initial_guess = [0.01, 0.02, 50]
-    base_circuit = BaseCircuit(initial_guess)
 
     # __init__()
     # check initial_guess is loaded in correctly
+    base_circuit = BaseCircuit(initial_guess)
     assert base_circuit.initial_guess == initial_guess
 
     # improper input_guess types raise an TypeError
@@ -34,37 +34,14 @@ def test_BaseCircuit():
         r == 8
 
     # fit()
-    # improper data types in fitting raise a TypeError
     with pytest.raises(TypeError):
         r = BaseCircuit(initial_guess=[.01, .005, .1, .0001, 200])
-        r.fit([42, 4.2], [])  # frequencies not ndarray
-
-    with pytest.raises(TypeError):
-        r = BaseCircuit(initial_guess=[.01, .005, .1, .0001, 200])
-        r.fit(np.array([42 + 42j]), [])  # frequencies not numeric type
-
-    with pytest.raises(TypeError):
-        r = BaseCircuit(initial_guess=[.01, .005, .1, .0001, 200])
-        r.fit(np.array([42]), [42 + 42j])  # Z not ndarray
-
-    with pytest.raises(TypeError):
-        r = BaseCircuit(initial_guess=[.01, .005, .1, .0001, 200])
-        r.fit(np.array([42]), np.array([0.5, 0.2]))  # Z not complex
+        r.fit(np.array([42 + 42j]), [])  # frequencies are complex
 
     with pytest.raises(TypeError):
         r = BaseCircuit(initial_guess=[.01, .005, .1, .0001, 200])
         r.fit(np.array([42, 4.2]), np.array([42 + 42j]))  # mismatched lengths
 
-    # predict()
-    # improper data types in fitting raise a TypeError
-    with pytest.raises(TypeError):
-        r = BaseCircuit(initial_guess=[.01, .005, .1, .0001, 200])
-        r.predict([42, 4.2])  # frequencies not ndarray
-
-    with pytest.raises(TypeError):
-        r = BaseCircuit(initial_guess=[.01, .005, .1, .0001, 200])
-        r.predict(np.array([42 + 42j]))  # frequencies not numeric type
-
     # plot()
     # kind = {'nyquist', 'bode'} should return a plt.Axes() object
     _, ax = plt.subplots()
@@ -95,7 +72,7 @@ def test_Randles():
 
     # compare with known impedance predictions
     assert np.isclose(randles.predict(np.array([10.0])),
-                      np.complex(0.0251618, -0.00601304))
+                      complex(0.0251618, -0.00601304))
 
     # check altair plotting with a fit circuit
     chart = randles.plot(f_data=f, Z_data=Z)
@@ -151,6 +128,10 @@ def test_CustomCircuit():
     assert np.isclose(np.real(custom_circuit.predict(high_f)[0]),
                       initial_guess[0])
 
+    # check complex frequencies raise TypeError
+    with pytest.raises(TypeError):
+        custom_circuit.predict([0.42, 42 + 42j])
+
     # __str()__
     initial_guess = [.01, .005, .1]
     custom_string = 'R0-p(R1,C1)'
